#version 330 core
in vec2 uv;
in vec3 normal;
in vec3 pos;

uniform sampler2D colorTexture;

uniform vec3 size;
uniform int food;
uniform vec3 light;

out vec4 color;

// shadow mapping
uniform samplerCube CubeMap;
uniform vec2 near_far; // near and far plane for cm-cams
in vec4 WS_pos;

void main()
{
    //vec2 newUV;
    //newUV.x = uv.x*size.x*2;
    //newUV.y = uv.y*size.x*2;
    
    float cos = 0.1;
    if (food > 0){
		//light is in worldSpace
		vec3 lightDir = normalize(light-pos);
		//float lightDistance = length(light-pos);
		cos = clamp(dot(normal,lightDir),0.1,1);
		//cos = dot(normal,lightDir)*(1-clamp(lightDistance/30.0,0.0,1.0));
		//cos = clamp(cos,0.1,1);

		// calculate vector from surface point to light position
		// (both positions are given in world space)
		vec3 cm_lookup_vec = WS_pos.xyz - light.xyz;

		// read depth value from cubemap shadow map
		float smallest_dist_to_light = texture(CubeMap, cm_lookup_vec).r;

		// WS dist-to-lightsource for current fragment
		float curr_fragment_dist_to_light = length(cm_lookup_vec);

		// undo previous [0;1]-mapping of dist-to-lightsource
		smallest_dist_to_light *= near_far.y;
	
		float eps = 0.15; // add a small offset (adjust as needed)
		if(smallest_dist_to_light+eps < curr_fragment_dist_to_light) {
			// fragment lies in shadow
			cos = 0.2f;
		}
    }

    //Intensity of light is 1...
    color = vec4(vec3(texture2D(colorTexture, uv)*cos),1);
}