#version 330 core
// Source: Omni-directional Shadows, Peter Houska
// Institute of Computer Graphics and Algorithms
in vec2 uv;
in vec3 normal;
in vec3 lightDir;

uniform sampler2D colorTexture;
out vec4 color;

// shadow mapping
uniform samplerCube CubeMap;
uniform vec3 light; //world space light position
uniform vec2 near_far; // near and far plane for cm-cams
in vec4 WS_pos;

void main()
{
	float cos = clamp(dot(normal,lightDir),0.2,1);

	// calculate vector from surface point to light position
	// (both positions are given in world space)
	vec3 cm_lookup_vec = WS_pos.xyz - light.xyz;

	// read depth value from cubemap shadow map
	float smallest_dist_to_light = texture(CubeMap, cm_lookup_vec).r;

	// WS dist-to-lightsource for current fragment
	float curr_fragment_dist_to_light = length(cm_lookup_vec);

	// undo previous [0;1]-mapping of dist-to-lightsource
	smallest_dist_to_light *= near_far.y;
	
	float eps = 0.15; // add a small offset (adjust as needed)
	if(smallest_dist_to_light+eps < curr_fragment_dist_to_light) {
		// fragment lies in shadow
		cos = 0.2f;
	}
		
	//Intensity of light is 1...		
	color = vec4(vec3(texture2D(colorTexture, uv)*cos),1);
	
}
